@@ -281,14 +281,6 @@ class Datafile(SirenComponent):
 
                 client.download_datafile(datafile_id, destination)
         """
-        def flatten_s3_file_path(s3_path):
-            from urllib.parse import urlparse
-            import ntpath
-            path = urlparse(s3_path)[2]  # [scheme, netloc, path, ...]
-            head, tail = ntpath.split(path)
-            file = tail or ntpath.basename(head)
-            return file
-
         # get the s3 keys
         # this requires access to be granted
         datafile = self._get_datafile(datafile_id)
@@ -300,12 +292,11 @@ class Datafile(SirenComponent):
         files = [f["path"] for f in datafile.files]
         filepaths = []
         for file in files:
-            if flatten:
-                file = flatten_s3_file_path(s3_path=file)
             try:
                 download_path = s3_access.download_files_from_s3_path(
                     s3_path=file,
-                    destination=destination
+                    destination=destination,
+                    flatten=flatten,
                 )
                 filepaths.extend(download_path)
             except Exception:
