@@ -31,23 +31,36 @@ class FileModel(AttributesDict):
         yield response.raw
         response.close()
 
-    def download(self, to='./'):
+    def download(self, to='./', flatten=False):
         """
         Download one or more files and save them in the user specified
         directory.
 
         :return: The path to the directory where the files were written.
         """
-        to = os.path.join(
+        to_path = os.path.join(
             to, urlparse(self.path).path.lstrip('/')
         )
         print(f'Downloading to: {to}...')
+        if flatten:
+            c_path, filename = os.path.split(to_path)
+            pd_path, as_of_date = os.path.split(c_path)
+            pd_path = pd_path[2:].replace('/', '-')
+            to_path = './{}-{}/{}'.format(pd_path, as_of_date[11:], filename)
 
-        directory, _ = os.path.split(to)
-        os.makedirs(directory, exist_ok=True)
+        if len(to_path) > 260 and os.name == 'nt':
+            raise Exception(f"Apologies {self.path} can't be downloaded "
+                            f"as the file name would be too long. You "
+                            f"may want to try calling again with "
+                            f"Instance.download(flatten=True), which "
+                            f"will put the file in a directory of your choice")
+
+        else:
+            directory, _ = os.path.split(to_path)
+            os.makedirs(directory, exist_ok=True)
 
         with self.open() as download_stream:
-            with open(to, 'wb') as target_download:
+            with open(to_path, 'wb') as target_download:
                 # copyfileobj is just a simple buffered
                 # file copy function with some sane
                 # defaults and optimisations.
@@ -56,4 +69,4 @@ class FileModel(AttributesDict):
                 )
                 print(f'Completed download to: {to}.')
 
-        return to
\ No newline at end of file
+        return to_path
\ No newline at end of file
