@@ -62,12 +62,9 @@ class SdkIntegrationTestCase(unittest.TestCase):
 
         s3_upload = patch('dli.client.s3.Client.upload_files_to_s3', _upload)
         s3_upload.start()
-        s3_download = patch('dli.client.s3.Client.download_files_from_s3_path')
-        self.s3_download_mock = s3_download.start()
 
         # cleanup
         self.addCleanup(s3_upload.stop)
-        self.addCleanup(s3_download.stop)
 
     @patch("dli.client.dli_client.Session._get_auth_key", lambda self: token)
     @patch("dli.client.dli_client.AnalyticsHandler", lambda self: None)
