@@ -1,4 +1,5 @@
 import os
+
 import pytest
 import tempfile
 
@@ -35,6 +36,7 @@ class DatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             data_as_of='2000-01-01'
         )
+        
         return datafile
 
     def test_get_unknown_datafile_raises_exception(self):
@@ -54,6 +56,7 @@ class DatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             data_as_of='2000-01-01'
         )
+        
 
         s3_datafile = self.client.get_s3_datafile(datafile.datafile_id)
         self.assertEqual(s3_datafile.datafile_id, datafile.datafile_id)
@@ -117,6 +120,7 @@ class DatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             data_as_of='2000-01-01'
         )
+        
 
         self.assertIsNotNone(datafile)
         self.assertEqual(datafile.dataset_id, dataset.dataset_id)
@@ -185,6 +189,7 @@ class DatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             data_as_of='2000-01-01'
         )
+        
 
         updated = self.client.add_files_to_datafile(
             datafile.datafile_id, 'prefix', [file2])
@@ -248,17 +253,29 @@ class DownloadDatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             '2000-01-01'
         )
+        
+        with patch('dli.client.s3.Client.download_files_from_s3_path') \
+                as s3_download:
+            with tempfile.TemporaryDirectory() as dest:
+                self.client.download_datafile(
+                    datafile.datafile_id,
+                    dest,
+                    flatten=False
+                )
 
-        with tempfile.TemporaryDirectory() as dest:
-            self.client.download_datafile(datafile.datafile_id, dest)
-
-            # validate we got the expected calls
-            self.s3_download_mock.assert_has_calls([
-                call(s3_path="s3://dev-ihsm-dl-pkg-test/prefix/MSFT.csv", destination=dest),
-                call(s3_path="s3://dev-ihsm-dl-pkg-test/prefix/AAPL.csv", destination=dest),
-            ],
-                any_order=True
-            )
+                # validate we got the expected calls
+                s3_download.assert_has_calls([
+                    call(
+                        destination=dest,
+                        flatten=False,
+                        s3_path="s3://dev-ihsm-dl-pkg-test/prefix/MSFT.csv",
+                    ),
+                    call(
+                        destination=dest,
+                        flatten=False,
+                        s3_path = "s3://dev-ihsm-dl-pkg-test/prefix/AAPL.csv",
+                    ),
+                ], any_order=True)
 
     def test_download_dataset_keeps_going_if_a_file_in_the_dataset_fails(self):
         def _download(_, file, dest):
@@ -276,6 +293,7 @@ class DownloadDatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             '2000-01-01'
         )
+        
 
         with self.assertRaises(DownloadFailed):
             with patch('dli.client.s3.Client.download_files_from_s3_path', _download) as s3_download:
@@ -320,6 +338,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             '2000-01-01'
         )
+        
 
         # assert the files were uploaded and that
         # their sizes have been resolved
@@ -350,6 +369,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             '2000-01-01'
         )
+        
 
         self.assertIn({
             "path": "s3://dev-ihsm-dl-pkg-test/prefix/AAPL.csv",
@@ -371,6 +391,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             '3210-1-1'
         )
+        
 
         assert self.client.get_datafile(datafile.datafile_id).data_as_of == '3210-01-01'
         assert {
@@ -391,7 +412,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 [sample_data],
                 "prefix",
                 '2019-11-123'
-        )
+            )
 
     def test_can_upload_datafile_files_recursively(self):
         sample_data = os.path.join(
@@ -406,6 +427,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             '2000-01-01'
         )
+        
 
         # assert the files were uploaded and that
         # their sizes have been resolved
@@ -462,6 +484,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 "prefix",
                 '2000-01-01'
             )
+            
 
             self.client.download_datafile(datafile.datafile_id, '/var/abc/')
 
@@ -515,6 +538,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 "prefix",
                 '2000-01-01'
             )
+            
 
             returned_list_of_files = self.client.download_datafile(
                 datafile.datafile_id,'/var/abc/'
@@ -556,6 +580,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 "prefix",
                 '2000-01-01'
             )
+            
 
             returned_list_of_files = self.client.download_datafile(
                 datafile.datafile_id, '/var/abc/', flatten=True)
@@ -566,4 +591,4 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 '/var/abc/AAPL.csv',
                 '/var/abc/master.txt'
             ]
-            assert returned_list_of_files == files_created
+            assert sorted(returned_list_of_files) == sorted(files_created)
