@@ -1,6 +1,8 @@
 import pytest
+import copy
 import os
 import io
+import pytest
 import tempfile
 import pyarrow
 import pandas
@@ -12,6 +14,62 @@ from dli.client.exceptions import DataframeStreamingException
 from unittest.mock import MagicMock, ANY
 
 
+def test_display_dataset(capsys, test_client, package_request,
+                         package_request_v2, dataset_request_index, 
+                         instance_request):
+    test_client._session.get.return_value.json.side_effect = [
+        package_request, package_request_v2,
+        dataset_request_index, instance_request,
+    ]
+
+    pp = test_client.packages(search_term="", only_mine=False)
+    ds = pp["Test Package"].datasets()
+    d = ds["Test DataSet"]
+    d.contents()
+    captured = capsys.readouterr()
+    assert captured.out == "\nINSTANCE 1\n"
+
+
+def test_retrieve_datasets(test_client, dataset_request_v1, dataset_request):
+    test_client._session.get.return_value.json.side_effect = [
+        dataset_request_v1, dataset_request
+    ]
+
+    # calls in the same way as package
+    pp = test_client.datasets(search_term="", only_mine=False)
+    assert len(pp) == 1
+
+
+def test_datasets_called_twice(test_client, package_request,
+                               package_request_v2, dataset_request_index):
+
+    test_client._session.get.return_value.json.side_effect = [
+        package_request, package_request_v2, dataset_request_index
+    ]
+    pp = test_client.packages(search_term="", only_mine=False)
+
+    #this should work twice
+    storm_datasets = pp["Test Package"].datasets()
+    storm_datasets = pp["Test Package"].datasets()
+
+
+def test_retrieve_instance_given_package_dataset(test_client,
+     package_request, package_request_v2,
+     dataset_request_index, instance_request
+):
+    test_client._session.get.return_value.json.side_effect = [
+        package_request, package_request_v2,
+        dataset_request_index, instance_request,
+    ]
+
+    pp = test_client.packages(search_term="", only_mine=False)
+    ds = pp["Test Package"].datasets()
+    d = ds["Test DataSet"]
+    instances = list(d.instances.all())
+    assert(len(instances) == 1)
+    assert(instances[0].datafile_id == 1)
+
+
 @pytest.fixture
 def instance_file(client):
     client._environment.consumption = 'consumption-test.local'
@@ -187,6 +245,128 @@ class TestDataset:
         )
 
 
+class TestFileDownload:
+
+    def test_instance_file_download_simple(self, client, instance_file):
+        old_dir = os.path.abspath(os.curdir)
+
+        with tempfile.TemporaryDirectory() as target_dest:
+            os.chdir(os.path.abspath(target_dest))
+            instance_file.download()
+            with open(os.path.join(target_dest, 'prefix/test.001.csv')) as f:
+                assert f.read() == 'hello world'
+
+        os.chdir(old_dir)
+
+    def test_instance_file_download_with_path(self, client, instance_file):
+        with tempfile.TemporaryDirectory() as target_dest:
+            instance_file.download(target_dest)
+            with open(os.path.join(target_dest, 'prefix/test.001.csv')) as f:
+                assert f.read() == 'hello world'
+
+    def test_instance_file_download_non_existent_path(
+        self, client, instance_file
+    ):
+        with tempfile.TemporaryDirectory() as target_dest:
+            target_dest = os.path.join(target_dest, 'a/b/c/')
+            instance_file.download(target_dest)
+            with open(os.path.join(
+                target_dest, 'prefix/test.001.csv'
+            )) as f:
+                assert f.read() == 'hello world'
+
+    def test_instance_file_download_non_existent_file(
+        self, client, instance_file
+    ):
+        with tempfile.TemporaryDirectory() as target_dest:
+            target_dest = os.path.join(target_dest, 'a')
+            instance_file.download(target_dest)
+            with open(os.path.join(
+                target_dest, 'prefix/test.001.csv'
+            )) as f:
+                assert f.read() == 'hello world'
+
+    def test_instance_file_overwrites(
+        self, client, instance_file
+    ):
+        with tempfile.TemporaryDirectory() as target_dest:
+            target_dest = os.path.join(target_dest, 'a')
+            instance_file.download(target_dest)
+            with open(os.path.join(
+                target_dest, 'prefix/test.001.csv'
+            )) as f:
+                assert f.read() == 'hello world'
+
+        client.session.reset_mock()
+        client._session.get().raw.read.side_effect = [
+            b'brave new world',
+            b''
+        ]
+
+        with tempfile.TemporaryDirectory() as target_dest:
+            target_dest = os.path.join(target_dest, 'a')
+            instance_file.download(target_dest)
+            with open(os.path.join(
+                target_dest, 'prefix/test.001.csv'
+            )) as f:
+                assert f.read() == 'brave new world'
+
+
+class TestInstanceDownload:
+
+    @pytest.fixture
+    def instance(self, client):
+        client._environment.consumption = 'consumption-test.local'
+
+        instance = client.Instance(
+            datafile_id='123'
+        )
+
+        client._session.get().json.return_value = {
+            'data': [{
+                'attributes': {
+                    'path': f's3://bucket/prefix/test.00{i}.csv',
+                    'metadata': {}
+                }
+            } for i in range(3)
+            ]
+        }
+
+        yield instance
+
+    def test_instance_download_all_should_refer_to_download_function(self, instance):
+        path = './target'
+        instance.download = Mock(return_value='file')
+        result = instance.download_all(path)
+
+        instance.download.assert_called_once_with(path)
+        assert result == 'file'
+
+    def test_instance_download(self, client, monkeypatch, instance):
+        client._session.get().raw = io.BytesIO(b'abc')
+
+        with tempfile.TemporaryDirectory() as target_dest:
+            target_dest = os.path.join(target_dest, 'a')
+            instance.download_all(target_dest)
+
+            assert (
+                sorted(os.listdir(os.path.join(target_dest, 'prefix'))) ==
+                ['test.000.csv', 'test.001.csv', 'test.002.csv']
+            )
+
+    def test_instance_download_flatten(self, client, monkeypatch, instance):
+        client._session.get().raw = io.BytesIO(b'abc')
+
+        with tempfile.TemporaryDirectory() as target_dest:
+            target_dest = os.path.join(target_dest, 'a')
+            instance.download(to=target_dest, flatten=True)
+
+            assert (
+                sorted(os.listdir(target_dest)) ==
+                ['test.000.csv', 'test.001.csv', 'test.002.csv']
+            )
+
+
 class TestInstanceDataframe:
 
     @pytest.fixture
@@ -499,64 +679,67 @@ class TestInstanceDownload:
             ]
 
 
-# class TestDatasetModule:
-#     def test_display_dataset(
-#             self, capsys, test_client, package_request,
-#             dataset_request, instance_request
-#     ):
-#
-#         test_client._session.get.return_value.json.side_effect = [
-#             package_request, dataset_request, instance_request,
-#         ]
-#
-#         pp = test_client.packages(search_term='')
-#         ds = pp['Test Package'].datasets()
-#         d = ds['Test DataSet']
-#         d.display()
-#         captured = capsys.readouterr()
-#         assert captured.out == '\nINSTANCE 1\n'
-#
-#     def test_retrieve_datasets(self, test_client, dataset_request_v1):
-#         test_client._session.get.return_value.json.side_effect = [
-#             dataset_request_v1,
-#             {
-#                 'data': {
-#                     'attributes': {
-#                         'short_code': 'test',
-#                         'location': {}
-#                     },
-#                     'id': 'test'
-#                 }
-#             }
-#         ]
-#
-#         # calls in the same way as package
-#         pp = test_client.datasets(search_term='', only_mine=False)
-#         assert len(pp) == 1
-#
-#     def test_datasets_called_twice(self, test_client,
-#                                    package_request, dataset_request):
-#
-#         test_client._session.get.return_value.json.side_effect = [
-#             package_request, dataset_request
-#         ]
-#         pp = test_client.packages(search_term='')
-#
-#         # This should work twice
-#         assert pp['Test Package'].datasets()
-#         assert pp['Test Package'].datasets()
-#
-#     def test_retrieve_instance_given_package_dataset(
-#         self, test_client,
-#         package_request, dataset_request, instance_request
-#     ):
-#         test_client._session.get.return_value.json.side_effect = [
-#             package_request, dataset_request, instance_request
-#         ]
-#
-#         pp = test_client.packages(search_term='')
-#         ds = pp['Test Package'].datasets()
-#         d = ds['Test DataSet']
-#         instances = list(d.instances.all())
-#         assert(len(instances) == 1)
-#         assert(instances[0].datafile_id == 1)
+class TestDatasetModule:
+    def test_display_dataset(
+            self, capsys, test_client, dataset_request_index, instance_request
+    ):
+        test_client._session.get.return_value.json.side_effect = [
+            instance_request,
+        ]
+
+        d = test_client.Dataset(
+            dataset_id='1',**dataset_request_index['data'][0]
+        )
+
+        d.contents()
+        captured = capsys.readouterr()
+        assert captured.out == '\nINSTANCE 1\n'
+
+    def test_retrieve_datasets(self, test_client, dataset_request_v1):
+        test_client._session.get.return_value.json.side_effect = [
+            dataset_request_v1,
+            {
+                'data': {
+                    'attributes': {
+                        'short_code': 'test',
+                        'location': {}
+                    },
+                    'id': 'test'
+                }
+            }
+        ]
+
+        # calls in the same way as package
+        pp = test_client.datasets(search_term='', only_mine=False)
+        assert len(pp) == 1
+
+    def test_datasets_called_twice(self, test_client,
+                                   package_request,
+                                   package_request_v2,
+                                   dataset_request_index):
+        test_client._session.get.return_value.json.side_effect = [
+            package_request, package_request_v2, package_request,
+            dataset_request_index
+        ]
+
+        pp = test_client.packages(search_term='')
+
+        # This should work twice
+        assert pp['Test Package'].datasets()
+        assert pp['Test Package'].datasets()
+
+    def test_retrieve_instance_given_package_dataset(
+        self, test_client, package_request_v2,
+        package_request, dataset_request_index, instance_request
+    ):
+        test_client._session.get.return_value.json.side_effect = [
+            package_request, package_request_v2,
+            package_request, dataset_request_index, instance_request
+        ]
+
+        pp = test_client.packages(search_term='')
+        ds = pp['Test Package'].datasets()
+        d = ds['Test DataSet']
+        instances = list(d.instances.all())
+        assert(len(instances) == 1)
+        assert(instances[0].datafile_id == 1)
