@@ -1,7 +1,11 @@
-from backports import tempfile
+import pytest
+import tempfile
+
 from tests.common import SdkIntegrationTestCase
+from unittest.mock import patch
 
 
+@pytest.mark.integration
 class SDKSamples(SdkIntegrationTestCase):
     """
     This spec is just meant to catch issues in terms of signature changes
@@ -34,7 +38,7 @@ class SDKSamples(SdkIntegrationTestCase):
         dataset_id = dataset.dataset_id
 
         # doc-start
-        # given a `dataset_id`, dataset metadata can be retrieved as 
+        # given a `dataset_id`, dataset metadata can be retrieved as
         dataset = client.get_dataset(dataset_id)
 
     def test_get_datafiles_in_dataset(self):
@@ -48,7 +52,8 @@ class SDKSamples(SdkIntegrationTestCase):
         datafile = client.register_datafile_metadata(
             dataset_id,
             "datafile_for_test_get_datafiles_in_dataset",
-            files
+            files,
+            '2000-01-01'
         )
 
         # doc-start
@@ -62,12 +67,7 @@ class SDKSamples(SdkIntegrationTestCase):
     def test_download_datafile(self):
         client = self.client
         package_id = self.create_package("package_for_test_download_datafile")
-        builder = self.dataset_builder(package_id, "dataset_for_test_download_datafile").with_external_s3_storage(
-            bucket_name="external-bucket",
-            aws_account_id=self.aws_account_id,
-            prefix="/"
-        )
-        dataset = client.register_dataset(builder)
+        dataset = self.register_s3_dataset(package_id, "dataset_for_test_download_datafile", "external-bucket", prefix="samples")
         dataset_id = dataset.dataset_id
 
         datafile = client.register_s3_datafile(
@@ -77,27 +77,29 @@ class SDKSamples(SdkIntegrationTestCase):
                 '../test_sandbox/samples/data/AAPL.csv',
                 '../test_sandbox/samples/data/MSFT.csv'
             ],
-            "samples/"
+            "samples/",
+            '2000-01-01'
         )
         datafile_id = datafile.datafile_id
 
-        with tempfile.TemporaryDirectory() as destination:
-            # doc-start
-            client.download_datafile(datafile_id, destination)
+        with patch('dli.client.s3.Client.download_files_from_s3_path') \
+                as s3_download:
+            with tempfile.TemporaryDirectory() as destination:
+                # doc-start
+                client.download_datafile(
+                    datafile_id,
+                    destination,
+                    flatten=False
+                )
 
-            import os
-            os.listdir(destination)  # shows: ['AAPL.csv', 'MSFT.csv']
+                import os
+                os.listdir(destination)  # shows: ['AAPL.csv', 'MSFT.csv']
 
     def test_create_datafile_in_dl_s3_storage(self):
         client = self.client
-        
+
         package_id = self.create_package("package_for_test_create_datafile_in_dl_s3_storage")
-        builder = self.dataset_builder(package_id, "dataset_for_test_create_datafile_in_dl_s3_storage").with_external_s3_storage(
-            bucket_name="external-bucket",
-            aws_account_id=self.aws_account_id,
-            prefix="/"
-        )
-        dataset = client.register_dataset(builder)
+        dataset = self.register_s3_dataset(package_id, "dataset_for_test_create_datafile_in_dl_s3_storage", "external-bucket")
         dataset_id = dataset.dataset_id
 
         # doc-start
@@ -111,18 +113,14 @@ class SDKSamples(SdkIntegrationTestCase):
                 '../test_sandbox/samples/data/AAPL.csv',
                 '../test_sandbox/samples/data/MSFT.csv'
             ],
-            s3_prefix="prefix/"
+            s3_prefix="prefix",
+            data_as_of='2000-01-01'
         )
 
     def test_create_datafile_in_external_s3_storage(self):
         client = self.client
         package_id = self.create_package("package_for_test_create_datafile_in_external_s3_storage")
-        builder = self.dataset_builder(package_id, "dataset_for_test_create_datafile_in_external_s3_storage").with_external_s3_storage(
-            bucket_name="external-bucket",
-            aws_account_id=self.aws_account_id,
-            prefix="/"
-        )
-        dataset = client.register_dataset(builder)
+        dataset = self.register_s3_dataset(package_id, "dataset_for_test_create_datafile_in_external_s3_storage", "external-bucket", prefix="path")
         dataset_id = dataset.dataset_id
 
         # doc-start
@@ -135,7 +133,8 @@ class SDKSamples(SdkIntegrationTestCase):
             files=[
                 {"path": "s3://external-bucket/path/to/file/A", "size": 10000},
                 {"path": "s3://external-bucket/path/to/file/B", "size": 15222}
-            ]
+            ],
+            data_as_of='2000-01-01'
         )
 
     def test_update_and_delete_datafile(self):
@@ -149,7 +148,8 @@ class SDKSamples(SdkIntegrationTestCase):
         datafile = client.register_datafile_metadata(
             dataset_id,
             "datafile_for_test_update_and_delete_datafile",
-            files
+            files,
+            '2000-01-01'
         )
 
         # doc-start
